@@ -5,10 +5,11 @@
 #' @param data a data.frame
 #' @return a list to be coerced into a zelig.call object
 #' @export
-#' @author Matt Owen \email{mowen@@iq.harvard.edu}
-zelig2blogit <- function(formula, ..., data) {
+#' @author James Honaker \email{zelig-zee@@iq.harvard.edu}
+zelig2blogit <- function(formula, weights=NULL, repweights=NULL, ..., data) {
   formula <- parse.formula(formula, "blogit")
   tmp <- cmvglm(formula, "blogit", 3)
+  built<-zeligBuildWeights(weights=weights, repweights=repweights, zeros="epsilon", data=data)
 
   
   # return list
@@ -16,6 +17,7 @@ zelig2blogit <- function(formula, ..., data) {
        .function = "vglm",
        
        formula = tmp$formula,
+       weights = built$weights,
        family  = blogit,
        data = data,
        constraints = tmp$constraints
