@@ -6,15 +6,17 @@
 #' @param data a \code{data.frame}
 #' @return a list to be coerced into a zelig.call object
 #' @export
-#' @author Matt Owen \email{mowen@@iq.harvard.edu}
-zelig2oprobit <- function(formula, weights=1, ..., data) {
+#' @author James Honaker \email{zelig-zee@@iq.harvard.edu}
+zelig2oprobit <- function(formula, weights=NULL, repweights=NULL, ..., data) {
+
+  built<-zeligBuildWeights(weights=weights, repweights=repweights, allowweights=FALSE, data=data)
+
   list(
        .function = "polr",
 
        formula = update(formula, as.factor(.) ~ .),
        method  = "probit",
-       # add weights + ignore, if empty, class later
-       # weights = weights,
+       weights = built$weights,
        Hess = TRUE,
        data = data
        )
